Algorithms for performing k-NN searches
Modules
- hnsw
- An approximate nearest neighbor index search data structure
Functions
- linear_
knn - Performs a linear knn search by iterating over everything in the space and performing a binary search on running set of neighbors.